#import "AddJobViewController.h"
#import "LanguageViewController.h"
#import "JobContainer.h"
#import "RESTJob.h"
#import "RESTLanguage.h"
#import <QuartzCore/QuartzCore.h>
#import "SBJson.h"


@implementation AddJobViewController

@synthesize textView;
@synthesize lc_srcButton;
@synthesize lc_tgtButton;
@synthesize tierButton;
@synthesize lgSrcCode;
@synthesize lgAry;
@synthesize lgTgtAry;
@synthesize lgPairsAry;
@synthesize lc_srcLabel;
@synthesize lc_tgtLabel;
@synthesize tierLabel;
@synthesize lgTgtCode;
@synthesize tier;
@synthesize alertBeforePost;
@synthesize finished;
@synthesize postFlg;

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
        self.title = NSLocalizedString(@"New Job", @"Master");
    }
    return self;
}

- (void)didReceiveMemoryWarning
{
    // Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
    
    // Release any cached data, images, etc that aren't in use.
}

#pragma mark - View lifecycle

- (void)viewDidLoad
{
    [super viewDidLoad];
    // Do any additional setup after loading the view from its nib.
    
    //Appearance of textView
    textView.layer.borderWidth = 1;
    textView.layer.borderColor = [[UIColor blackColor]CGColor];
    textView.layer.cornerRadius = 8;
    
    //Add the POST button to the navigation bar
    UIBarButtonItem *postButton = [[UIBarButtonItem alloc]
                            initWithTitle:@"POST"
                            style:UIBarButtonItemStyleBordered
                            target:self
                            action:@selector(postJob)
                            ];
    self.navigationItem.rightBarButtonItem = postButton; 
    
    //Apeearnace of language code labels
  
    
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}


- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    lc_srcButton.titleLabel.lineBreakMode = UILineBreakModeTailTruncation;
    
    //Set the Language Code(From) text
    
    if(lgSrcCode ){
        lc_srcLabel.text = [self getLanguageName:lgSrcCode];
        lc_tgtLabel.text = @"Select";
        tierLabel.text = @"Select";
    }
    
    if(lgTgtCode){
        lc_tgtLabel.text = [self getLanguageName:lgTgtCode];
        tierLabel.text = @"Select";
    }
    
    if(tier){
        tierLabel.text = self.tier;
    }
    
}



- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}

-(void)postJob{
    
    //Validation
    if (!lgSrcCode || !lgTgtCode || !tier) {
        UIAlertView *alert = [[UIAlertView alloc]  
                              initWithTitle:@"Warning:"  
                              message:@"Translation Settings not yet done!"  
                              delegate:self  
                              cancelButtonTitle:@"OK"  
                              otherButtonTitles:nil];  
        [alert show];
        
        return;
    }
    
    //get the original text
    NSString *viewText = textView.text;
    //Create the slug
    NSString *slug = [[[NSString alloc]init]autorelease];
    NSUInteger viewTextCount = [viewText length];
    if (viewTextCount >= 20) {
        slug = [NSString stringWithFormat:@"%@...",[viewText substringToIndex:20]];
    }else{
        slug = viewText;
    }
    
    NSNumber *num1 = [[NSNumber alloc]initWithInt:1];
    
    
    //alert before posting
    NSString *unitString = [[[NSString alloc]init]autorelease];
    for(NSDictionary *d in lgAry){
        NSString *lc = [d objectForKey:@"lc"];
        if([lc isEqualToString:lgSrcCode]){
            unitString = [d objectForKey:@"unit_type"];
        }
    }
        
    NSString *upString = [[[NSString alloc]init]autorelease];
    for(NSDictionary *d in lgPairsAry){
        NSString *lc_src = [d objectForKey:@"lc_src"];
        NSString *lc_tgt = [d objectForKey:@"lc_tgt"];
        NSString *tier_tmp = [d objectForKey:@"tier"];
        if([lc_src isEqualToString:lgSrcCode] && [lc_tgt isEqualToString:lgTgtCode] && [tier_tmp isEqualToString:tier]){
            upString = [d objectForKey:@"unit_price"];
        }
    }

    float up = [upString floatValue];
    float credits = up * [self countString:viewText Unit:unitString];
    
    NSString *msg = [[NSString alloc]initWithFormat:@"This job will cost %.2f points", credits];
    
    alertBeforePost = [[UIAlertView alloc]  
                          initWithTitle:@"Confirm:"  
                          message:msg 
                          delegate:self  
                          cancelButtonTitle:@"OK"  
                          otherButtonTitles:@"Cancel",nil];  
    self.postFlg = NO;
    [alertBeforePost show];

    self.finished = NO;
    while (!self.finished) {
        [[NSRunLoop currentRunLoop]
         runUntilDate:[NSDate dateWithTimeIntervalSinceNow:0.5]];
    }
    
    //only when postFlg = YES, continue the process
    if(self.postFlg){
        NSMutableDictionary *job = [NSMutableDictionary dictionaryWithObjectsAndKeys:
                                    @"text",@"type",
                                    slug,@"slug",
                                    viewText,@"body_src",
                                    lgSrcCode,@"lc_src",
                                    lgTgtCode,@"lc_tgt",
                                    tier,@"tier",
                                    num1, @"force",
                                    num1, @"auto_approve",
                                    nil];
        
        //call API
        RESTJob *restJob = [[RESTJob alloc]init];
        NSDictionary *jsonDictionary = [restJob postTranslateJob:job];
        [restJob release];
        
        //save to the plist
        JobContainer *jc = [[JobContainer alloc]init];
        NSString *opstat = [jsonDictionary objectForKey:@"opstat"];
        if ([opstat isEqualToString:@"ok"]) {
            NSString *job_id = [[[jsonDictionary objectForKey:@"response"]objectForKey:@"job"]objectForKey:@"job_id"];
            NSString *status = [[[jsonDictionary objectForKey:@"response"]objectForKey:@"job"]objectForKey:@"status"];
            NSString *credits = [[[jsonDictionary objectForKey:@"response"]objectForKey:@"job"]objectForKey:@"credits"];
 
            [job setValue:job_id forKey:@"job_id"];
            [job setValue:status forKey:@"status"];
            [job setValue:credits forKey:@"credits"];

            [jc appendJob:job];
        }
        
        //view transition
        textView.text = nil;
        
        [self.navigationController popViewControllerAnimated:YES];

    }else{
        return;
    }
    
    
        
}

-(void)getLanguageSrc:(id)sender{
    
    RESTLanguage *restLanguage = [[[RESTLanguage alloc]init]autorelease];
    NSDictionary *jsonDictionary = [restLanguage getLanguage];
    lgAry= [jsonDictionary objectForKey:@"response"];
        
    //view transition
    LanguageViewController *lgvc = [[[LanguageViewController alloc]initWithNibName:@"LanguageViewController" bundle:nil]autorelease];
    
    lgvc.lgAry = lgAry;
    lgvc.title = @"Translation Setting";
    lgvc.lblName = @"Source Language";
    
    [self.navigationController pushViewController:lgvc animated:YES];

}

-(IBAction)getLanguageTgt:(id)sender{
    
    if(lgSrcCode){
        RESTLanguage *restLanguage = [[[RESTLanguage alloc]init]autorelease];
        NSString *lg_src = [self getLanguageCode:self.lc_srcLabel.text];
        NSDictionary *jsonDictionary = [restLanguage getLanguagePairs:lg_src];
        lgPairsAry = [jsonDictionary objectForKey:@"response"];
        
        NSMutableArray *tmpAry = [[[NSMutableArray alloc]init]autorelease];
        
        for(NSDictionary *dict in lgPairsAry){
            NSString *src = [dict objectForKey:@"lc_src"];
            NSString *tgt = [dict objectForKey:@"lc_tgt"];
            if([src isEqualToString:lg_src]){
                [tmpAry addObject:tgt];                
            }
        }

        
        
        NSSet *uniqueSet = [NSSet setWithArray:tmpAry];
        

        NSArray *uniqueAry = [uniqueSet allObjects];

        
        lgTgtAry = [[[NSMutableArray alloc]init]autorelease];
        for(NSString *lc in uniqueAry){
            NSString *language = [self getLanguageName:lc];
            NSDictionary *dict = [[NSDictionary alloc]initWithObjectsAndKeys:language,@"language",
                                                                             lc,@"lc",nil];
            [lgTgtAry addObject:dict];

        }
        
        
        //view transition
        LanguageViewController *lgvc = [[LanguageViewController alloc]initWithNibName:@"LanguageViewController" bundle:nil];
        lgvc.lgAry = lgTgtAry;
        lgvc.title = @"Translation Setting";
        lgvc.lblName = @"Target Language";
        [self.navigationController pushViewController:lgvc animated:YES];
        [lgvc release];

        
    }else{
        //display the alert view
        UIAlertView *alert = [[UIAlertView alloc]  
                              initWithTitle:@"Warning:"  
                              message:@"First enter the source language code"  
                              delegate:self  
                              cancelButtonTitle:@"OK"  
                              otherButtonTitles:nil];  
        [alert show];

        
    }
    
}

-(IBAction)getTier:(id)sender{
    if(!lgSrcCode || !lgTgtCode){
        //display the alert view
        UIAlertView *alert = [[UIAlertView alloc]  
                              initWithTitle:@"Warning:"  
                              message:@"Enter the language code"  
                              delegate:self  
                              cancelButtonTitle:@"OK"  
                              otherButtonTitles:nil];
        [alert show];

    }else{

        
        NSMutableArray *tierAry = [[[NSMutableArray alloc]init]autorelease];
        //get tiers from lg_src and lg_tgt
        for(NSDictionary *dict in lgPairsAry){
            NSString *tgt = [dict objectForKey:@"lc_tgt"];
            if ([tgt isEqualToString:lgTgtCode]) {
                NSString *t = [dict objectForKey:@"tier"];
                
                NSDictionary *d = [[NSDictionary alloc]initWithObjectsAndKeys:t,@"language",
                                                                            t,@"lc",nil];
                
                [tierAry addObject:d];
            }
        }
        
        //view transition
        LanguageViewController *lgvc = [[LanguageViewController alloc]initWithNibName:@"LanguageViewController" bundle:nil];
        lgvc.lgAry = tierAry;
        lgvc.title = @"Translation Tier";
        lgvc.lblName = @"Tier";
        [self.navigationController pushViewController:lgvc animated:YES];
        [lgvc release];
        
    }
    
}



-(NSString*)getLanguageName:(NSString*)code{
    NSString *name;
    for (NSDictionary *dict in self.lgAry){
        if([[dict objectForKey:@"lc"] isEqualToString:code]){
            name = [dict objectForKey:@"language"];
        }
    
    }
    
    return name;
}

-(NSString*)getLanguageCode:(NSString*)name{
    NSString *code;
    for (NSDictionary *dict in self.lgAry){
        if([[dict objectForKey:@"language"] isEqualToString:name]){
            code = [dict objectForKey:@"lc"];
        }
        
    }

    return code;
}


//calculate text length(word/character)
-(NSInteger)countString:(NSString*)string Unit:(NSString*)unit{
    if ([unit isEqualToString:@"word"]) {
        
        NSCharacterSet *separators = [NSCharacterSet whitespaceAndNewlineCharacterSet];
        NSArray *words = [string componentsSeparatedByCharactersInSet:separators];
        NSIndexSet *separatorIndexes = [words indexesOfObjectsPassingTest:^BOOL(id obj, NSUInteger idx, BOOL *stop) {
            return [obj isEqualToString:@""];
        }];
        
        return [words count] - [separatorIndexes count];

        
    }

    if([unit isEqualToString:@"character"]){
        NSString *s = [string stringByReplacingOccurrencesOfString:@" " withString:@""];
        NSInteger count = [s length];
        return count;
    }
    

}

- (void)alertView:(UIAlertView *)alertView clickedButtonAtIndex:(NSInteger)buttonIndex{
    if([alertView isEqual:alertBeforePost]){
        switch (buttonIndex){
            case 0:
                finished = YES;
                postFlg = YES;

                break;
            
            case 1:
                finished = YES;
                postFlg = NO;
                
                break;
                        
            default:

                break;
                
        }
    }
    
}

- (NSString*)_uriEncodeForString:(NSString *)str {
    return [((NSString*)CFURLCreateStringByAddingPercentEscapes(kCFAllocatorDefault,
                                                                (CFStringRef)str,
                                                                NULL,
                                                                (CFStringRef)@"!*'();:@&=+$,/?%#[]",
                                                                kCFStringEncodingUTF8)) autorelease];
}


-(NSMutableString*)decodeUFT8:(NSString*)string{
    NSMutableString* result = [[NSMutableString alloc] init];

    for (NSUInteger i = 0; i < string.length; i++)        
    {
        unichar code = [string characterAtIndex:i];
        [result appendFormat:@"\\u%04x", code];
        
    }
    return result;
}


-(NSString*)convertUTF8:(NSString*)string{
    NSData *data = [string dataUsingEncoding:NSUTF8StringEncoding];
    NSMutableString* result = [[NSMutableString alloc] init];
    const char* utf8 = (const char*)data.bytes;
    for (NSUInteger i = 0; i < data.length; i++){
        char word = *(utf8 + i);
        NSUInteger location = 0;
        while ((word & 0x80) == 0x80){
            location++;
            word <<= 1;
        }
        word >>= location;
        SInt64 code = (UInt32)(word + (word < 0 ? 256 : 0));
        while (true) {
            char next_word = (i+1 < data.length ? *(utf8 + i + 1) : 0);
            if ((next_word & 0xC0) == 0x80){
                code = code * 0x40 + (next_word & 0x3F);
            }
            else{
                break;
            }
            i++;
        }
        [result appendFormat:@"\\u%04x", code];
    }
    return result;
}
@end