
#import "AppDelegate.h"
#import "MasterViewController.h"
#import "DetailViewController.h"
#import "AddJobViewController.h"
#import "LanguageViewController.h"

@implementation AppDelegate

@synthesize window = _window;
@synthesize navigationController = _navigationController;
@synthesize splitViewController = _splitViewController;

- (void)dealloc
{
    [_window release];
    [_navigationController release];
    [_splitViewController release];
    [super dealloc];
}

- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions
{
    self.window = [[[UIWindow alloc] initWithFrame:[[UIScreen mainScreen] bounds]] autorelease];
    // Override point for customization after application launch.
    if ([[UIDevice currentDevice] userInterfaceIdiom] == UIUserInterfaceIdiomPhone) {
        MasterViewController *masterViewController = [[[MasterViewController alloc] initWithNibName:@"MasterViewController_iPhone" bundle:nil] autorelease];        
        self.navigationController = [[[UINavigationController alloc] initWithRootViewController:masterViewController] autorelease];
        self.window.rootViewController = self.navigationController;
    } else {
        MasterViewController *masterViewController = [[[MasterViewController alloc] initWithNibName:@"MasterViewController_iPad" bundle:nil] autorelease];
        UINavigationController *masterNavigationController = [[[UINavigationController alloc] initWithRootViewController:masterViewController] autorelease];
        
        DetailViewController *detailViewController = [[[DetailViewController alloc] initWithNibName:@"DetailViewController_iPad" bundle:nil] autorelease];
        UINavigationController *detailNavigationController = [[[UINavigationController alloc] initWithRootViewController:detailViewController] autorelease];
    	
        self.splitViewController = [[[UISplitViewController alloc] init] autorelease];
        self.splitViewController.delegate = detailViewController;
        self.splitViewController.viewControllers = [NSArray arrayWithObjects:masterNavigationController, detailNavigationController, nil];
        
        self.window.rootViewController = self.splitViewController;
    }
    [self.window makeKeyAndVisible];
    return YES;
}

- (void)applicationWillResignActive:(UIApplication *)application
{
    /*
     Sent when the application is about to move from active to inactive state. This can occur for certain types of temporary interruptions (such as an incoming phone call or SMS message) or when the user quits the application and it begins the transition to the background state.
     Use this method to pause ongoing tasks, disable timers, and throttle down OpenGL ES frame rates. Games should use this method to pause the game.
     */
}

- (void)applicationDidEnterBackground:(UIApplication *)application
{
    /*
     Use this method to release shared resources, save user data, invalidate timers, and store enough application state information to restore your application to its current state in case it is terminated later. 
     If your application supports background execution, this method is called instead of applicationWillTerminate: when the user quits.
     */
}

- (void)applicationWillEnterForeground:(UIApplication *)application
{
    /*
     Called as part of the transition from the background to the inactive state; here you can undo many of the changes made on entering the background.
     */
}

- (void)applicationDidBecomeActive:(UIApplication *)application
{
    /*
     Restart any tasks that were paused (or not yet started) while the application was inactive. If the application was previously in the background, optionally refresh the user interface.
     */
}

- (void)applicationWillTerminate:(UIApplication *)application
{
    /*
     Called when the application is about to terminate.
     Save data if appropriate.
     See also applicationDidEnterBackground:.
     */
}


-(NSString*)convertUTF8:(NSString*)string{
    
    NSData *data = [string dataUsingEncoding:NSUTF8StringEncoding];
    
    NSMutableString* result = [[NSMutableString alloc] init];
    
    
    
    // UTF-8 形式のバイト列を、操作しやすいように const char* 型で取得します。
    
    const char* utf8 = (const char*)data.bytes;
    
    
    
    // 全文字分の処理を行います。
    
    for (NSUInteger i = 0; i < data.length; i++)
        
    {
        
        char word = *(utf8 + i);
        
        
        
        // 最初は UTF-8 文字の 1 バイト目であると想定しつつ、頭のビットに 0 が登場する位置を探します。
        
        NSUInteger location = 0;
        
        
        
        while ((word & 0x80) == 0x80)
            
        {
            
            location++;
            
            word <<= 1;
            
        }
        
        
        
        // 元の値から頭のフラグを全て落とした値にします。
        
        word >>= location;
        
        
        
        // 続くバイトデータを考慮しながら、Unicode 1 文字としての文字コードを計算します。
        
        // iOS 5.0 SDK では char は符号付整数のため、マイナスの値をプラスに変換しています。
        
        SInt64 code = (UInt32)(word + (word < 0 ? 256 : 0));
        
        
        
        while (true)
            
        {
            
            // 次のバイトデータを取得します。末尾の場合は 0 とします。
            
            char next_word = (i+1 < data.length ? *(utf8 + i + 1) : 0);
            
            
            
            // 2 バイト目のデータであれば、その値を文字コードに反映します。
            
            if ((next_word & 0xC0) == 0x80)
                
            {
                
                // 頭のフラグを除いた値を、文字コードに加えて行きます。
                
                code = code * 0x40 + (next_word & 0x3F);
                
            }
            
            else
                
            {
                
                // 次の文字が UTF-8 での 1 文字目を構成する先頭バイトの場合は、文字コードの計算処理を終了します。
                
                break;
                
            }
            
            
            
            // 次の文字位置に移動します。
            
            i++;
            
        }
        
        
        
        // 取得できた文字コードを '\uXXXX' 形式に変換します。
        
        [result appendFormat:@"\\u%04x", code];
        
    }
    
    return result;
}





@end
