#import "DetailViewController.h"
#import "RESTJob.h"
#import "JobContainer.h"
#import <QuartzCore/QuartzCore.h>


@interface DetailViewController ()
@property (strong, nonatomic) UIPopoverController *masterPopoverController;
- (void)configureView;
@end

@implementation DetailViewController

@synthesize detailItem = _detailItem;
@synthesize detailDescriptionLabel = _detailDescriptionLabel;
@synthesize masterPopoverController = _masterPopoverController;

@synthesize body_src;
@synthesize body_srcView;

@synthesize body_tgt;
@synthesize body_tgtView;

@synthesize job_id;
@synthesize job_idLabel;

@synthesize tier;
@synthesize tierLabel;

@synthesize credits;
@synthesize creditsLabel;

@synthesize lc_src;
@synthesize lc_srcLabel;

@synthesize lc_tgt;
@synthesize lc_tgtLabel;

@synthesize status;
@synthesize statusLabel;

@synthesize cancelButton;
@synthesize updateButton;

- (void)dealloc
{
    [_detailItem release];
    [_detailDescriptionLabel release];
    [_masterPopoverController release];
    [super dealloc];
}

#pragma mark - Managing the detail item

- (void)setDetailItem:(id)newDetailItem
{
    if (_detailItem != newDetailItem) {
        [_detailItem release]; 
        _detailItem = [newDetailItem retain]; 

        // Update the view.
        [self configureView];
    }

    if (self.masterPopoverController != nil) {
        [self.masterPopoverController dismissPopoverAnimated:YES];
    }        
}

- (void)configureView
{
    // Update the user interface for the detail item.

    if (self.detailItem) {
        self.detailDescriptionLabel.text = [self.detailItem description];
    }
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Release any cached data, images, etc that aren't in use.
}

#pragma mark - View lifecycle

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
    [self configureView];

    job_idLabel.text = job_id;
    tierLabel.text = tier;
    creditsLabel.text = [[NSString alloc]initWithFormat:@"%@Point",credits];
    lc_srcLabel.text = lc_src;
    lc_tgtLabel.text = lc_tgt;
    statusLabel.text = status;
    body_srcView.text = body_src;
    body_tgtView.text = body_tgt;
    

    body_srcView.layer.borderWidth = 1;
    body_srcView.layer.borderColor = [[UIColor blackColor]CGColor];
    body_srcView.layer.cornerRadius = 8;

    body_tgtView.layer.borderWidth = 1;
    body_tgtView.layer.borderColor = [[UIColor blackColor]CGColor];
    body_tgtView.layer.cornerRadius = 8;
    
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
}

- (void)viewDidAppear:(BOOL)animated
{
    [super viewDidAppear:animated];
    

}

- (void)viewWillDisappear:(BOOL)animated
{
	[super viewWillDisappear:animated];
}

- (void)viewDidDisappear:(BOOL)animated
{
	[super viewDidDisappear:animated];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    // Return YES for supported orientations
    if ([[UIDevice currentDevice] userInterfaceIdiom] == UIUserInterfaceIdiomPhone) {
        return (interfaceOrientation != UIInterfaceOrientationPortraitUpsideDown);
    } else {
        return YES;
    }
}

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        self.title = NSLocalizedString(@"Job Detail", @"Detail");
    }
    return self;
}
							
#pragma mark - Split view

- (void)splitViewController:(UISplitViewController *)splitController willHideViewController:(UIViewController *)viewController withBarButtonItem:(UIBarButtonItem *)barButtonItem forPopoverController:(UIPopoverController *)popoverController
{
    barButtonItem.title = NSLocalizedString(@"Master_1", @"Master_2");
    [self.navigationItem setLeftBarButtonItem:barButtonItem animated:YES];
    self.masterPopoverController = popoverController;
}

- (void)splitViewController:(UISplitViewController *)splitController willShowViewController:(UIViewController *)viewController invalidatingBarButtonItem:(UIBarButtonItem *)barButtonItem
{
    // Called when the view is shown again in the split view, invalidating the button and popover controller.
    [self.navigationItem setLeftBarButtonItem:nil animated:YES];
    self.masterPopoverController = nil;
}


-(void)cancelJob:(id)sender{
    
    if([status isEqualToString:@"available"]){
        //display alert view
        UIAlertView *alert = [[UIAlertView alloc]  
                              initWithTitle:@"Confirm:"  
                              message:@"Do you cancel this job?"  
                              delegate:self  
                              cancelButtonTitle:@"Stop"  
                              otherButtonTitles:@"Continue",nil];  
        [alert show];

        
    }else{
        UIAlertView *alert = [[UIAlertView alloc]  
                              initWithTitle:@"Warning:"  
                              message:@"Only in <available>status you can cacel the job!"  
                              delegate:self  
                              cancelButtonTitle:@"OK"  
                              otherButtonTitles:nil];  
        [alert show];
        
    }
    
}

-(void)alertView:(UIAlertView*)alert clickedButtonAtIndex:(NSInteger)buttonIndex {
    
    switch (buttonIndex) {
        case 0:
            break;
        case 1:{
            
            //delete the job from the plist file
            RESTJob *restJob = [[RESTJob alloc]init];
            NSDictionary *responseDictionary = [restJob deleteTranslateJob:job_id];
            NSString *opstat = [responseDictionary objectForKey:@"opstat"];
            if ([opstat isEqualToString:@"ok"]) {
                JobContainer *jc = [[[JobContainer alloc]init]autorelease];
                [jc deleteJob:job_id];
                
            //go back to the previous view
                [self.navigationController popViewControllerAnimated:YES];
            }
            break;
        }
        default:
            break;
    }        
    
}

-(void)updateJob:(id)sender{
    RESTJob *restJob = [[RESTJob alloc]init];
    NSDictionary *responseDictionary = [restJob getTranslateJob:job_id];
    NSString *opstat = [responseDictionary objectForKey:@"opstat"];
    
    if ([opstat isEqualToString:@"ok"]) {
        JobContainer *jc = [[[JobContainer alloc]init]autorelease];
        [jc updateJob:job_id job:responseDictionary];
        
        //update the job on the plist
        NSDictionary *job = [jc getJob:job_id];
        statusLabel.text = [job objectForKey:@"status"];
        body_tgtView.text = [job objectForKey:@"body_tgt"];
        
    }

}




@end
