#import "RESTClient.h"
#import "SBJson.h"

@implementation RESTClient

-(id)init{
    NSBundle* mainBundle;
    mainBundle = [NSBundle mainBundle];
    NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
    NSString *path = [[paths objectAtIndex:0]stringByAppendingPathComponent:@"Account.plist"];
    
    NSDictionary *keys = [[NSDictionary alloc]initWithContentsOfFile:path];

    api_key = [keys objectForKey:@"api_key"];
    private_key = [keys objectForKey:@"private key"];
    
    timestamp = [NSString stringWithFormat:@"%0.0f", [[NSDate date] timeIntervalSince1970]];
    return self;    
}


-(NSString*)rest:(NSString*)urlString Method:(NSString*)_method Parameter:(NSDictionary *)param{
    
    NSURL *url = [NSURL URLWithString:urlString];
    
     
    // Create a request object using the URL.
    NSMutableURLRequest *request = [NSMutableURLRequest requestWithURL:url];
    
    //set HTTP header
    [request setValue:@"application/x-www-form-urlencoded; charset=utf-8" forHTTPHeaderField:@"Content-Type"];
    [request setValue:@"application/json" forHTTPHeaderField:@"Accept"];    
    [request setHTTPMethod:_method];
    
    //make HTTPbody string
    NSString *bodyString = [self _buildParameters:param];
    NSData   *httpBody   = [bodyString dataUsingEncoding:NSUTF8StringEncoding];
    if(![_method isEqualToString:@"GET"]){
        [request setValue:[NSString stringWithFormat:@"%d", [httpBody length]] forHTTPHeaderField:@"Content-Length"];
        [request setHTTPBody:httpBody];
        }
    
    // Prepare for the response back from the server    
    NSHTTPURLResponse *response = nil;
    NSError *error = nil;
    
    // Send a synchronous request to the server (i.e. sit and wait for the response)
    NSData *responseData = [NSURLConnection sendSynchronousRequest:request returningResponse:&response error:&error];
    
    // Check if an error occurred    
    if (error != nil) {
        NSLog(@"%@", [error localizedDescription]);
        // Do something to handle/advise user.
    }
    
    // Convert the response data to a string.
    NSString *responseString = [[NSString alloc] initWithData:responseData  encoding:NSUTF8StringEncoding];
    
    return responseString;    
}

//make a query parameter
- (NSString*)_buildParameters:(NSDictionary *)params {
    NSMutableString *s = [NSMutableString string];
    
    NSString *key;
    for ( key in params ) {
        NSString *uriEncodedValue = [self _uriEncodeForString:[params objectForKey:key]];
        [s appendFormat:@"%@=%@&", key, uriEncodedValue];
    }
    
    if ( [s length] > 0 ) {
        [s deleteCharactersInRange:NSMakeRange([s length]-1, 1)];
    }
    return s;
}

- (NSString*)_uriEncodeForString:(NSString *)str {
    return [((NSString*)CFURLCreateStringByAddingPercentEscapes(kCFAllocatorDefault,
                                                                (CFStringRef)str,
                                                                NULL,
                                                                (CFStringRef)@"!*'();:@&=+$,/?%#[]",
                                                                kCFStringEncodingUTF8)) autorelease];
}





@end
